# Zgulde's Python Utilities

A collection of miscellaneous helper functions and classes that I find useful.
Maybe you will too!

To install/upgrade:

```
python -m pip install --upgrade zgulde
```

## Pandas Extensions

The most polished of all of these modules is `extend_pandas`. It provides some
extensions to [pandas](http://pandas.pydata.org/) that I've found useful.

Usage:

```python
# from within a python script / jupyter notebook, etc
import zgulde.extend_pandas
# now you can use all the additional methods
```

[Further documentation can be found here](https://zgulde.github.io/zgulde-python/), or by looking at the built-in
help:

```python
import zgulde.extend_pandas
help(zgulde.extend_pandas)
```

## Other Modules

Are in various stages of completeness, and documentation for them (if present)
can be found within docstrings in the module.
